package WebGUI::i18n::Dutch::AuthWebGUI;
use utf8;
our $I18N = {
  1 => {
    'lastUpdated' => '1155557680',
    'message' => 'WebGUI authenticatie opties'
  },
  10 => {
    'lastUpdated' => '1155557689',
    'message' => 'Oude wachtwoord'
  },
  11 => {
    'lastUpdated' => '1155557698',
    'message' => 'Nieuwe wachtwoord'
  },
  12 => {
    'lastUpdated' => '1155557724',
    'message' => 'Het nieuwe wachtwoord mag niet overeenkomen met het oude wachtwoord'
  },
  13 => {
    'lastUpdated' => '1155558103',
    'message' => 'Wachtwoord ophalen toestaan?'
  },
  14 => {
    'lastUpdated' => '1155557758',
    'message' => 'Minimale wachtwoordlengte'
  },
  15 => {
    'lastUpdated' => '1155557790',
    'message' => 'Minimale wachtwoordlengte'
  },
  '15 help' => {
    'lastUpdated' => '1227626094',
    'message' => 'De vereiste minimale lengte van wachtwoorden in aantal karakters.'
  },
  16 => {
    'lastUpdated' => '1155557815',
    'message' => 'Wachtwoord verloopt na'
  },
  '16 help' => {
    'lastUpdated' => '1227626356',
    'message' => 'Dit bepaalt hoe lang een wachtwoord geldig is. Als deze periode verlopen is, wordt de gebruiker gevraagd een nieuw wachtwoord op te geven.'
  },
  17 => {
    'lastUpdated' => '1155557826',
    'message' => 'Wachtwoord gewijzigd'
  },
  18 => {
    'lastUpdated' => '1155557897',
    'message' => 'Wijzigen wachtwoord toestaan?'
  },
  '18 help' => {
    'lastUpdated' => '1227626448',
    'message' => 'Kunnen gebruikers hun eigen wachtwoord aanpassen? Let op dat dit in samenwerking met de timeouts een hoop werk voor de beheerder kan opleveren.'
  },
  19 => {
    'lastUpdated' => '1155557876',
    'message' => 'Wijzigen gebruikersnaam toestaan?'
  },
  '19 help' => {
    'lastUpdated' => '1227626478',
    'message' => 'Kunnen gebruikers hun gebruikersnaam aanpassen na het aanmaken van hun account?'
  },
  2 => {
    'lastUpdated' => '1155557889',
    'message' => 'Wachtwoord (bevestiging)'
  },
  20 => {
    'lastUpdated' => '1155557910',
    'message' => 'Wijzigen wachtwoord toestaan?'
  },
  21 => {
    'lastUpdated' => '1155557921',
    'message' => 'Wijzigen gebruikersnaam toestaan?'
  },
  22 => {
    'lastUpdated' => '1155558006',
    'message' => 'Er zijn geen velden om te wijzigen. '
  },
  3 => {
    'lastUpdated' => '1155557957',
    'message' => 'De ingevulde wachtwoorden komen niet overeen. Probeer het nogmaals.'
  },
  4 => {
    'lastUpdated' => '1155557998',
    'message' => 'Het wachtwoord moet worden ingevuld.'
  },
  5 => {
    'lastUpdated' => '1155557989',
    'message' => 'Het wachtwoord mag niet &quot;password&quot; zijn.'
  },
  6 => {
    'lastUpdated' => '1155558094',
    'message' => 'Wachtwoord ophalen toestaan?'
  },
  7 => {
    'lastUpdated' => '1155558075',
    'message' => 'Wachtwoorden moeten minimaal het aantal karakters hebben van: '
  },
  8 => {
    'lastUpdated' => '1155558115',
    'message' => 'Uw wachtwoord is verlopen.'
  },
  9 => {
    'lastUpdated' => '1155558138',
    'message' => 'Wachtwoorden laten verlopen bij het aanmaken van gebruikers?'
  },
  '9 help' => {
    'lastUpdated' => '1227626506',
    'message' => 'Dit laat een wachtwoord direct na het aanmaken van een account verlopen.'
  },
  'Password Recovery Email Template' => {
    'lastUpdated' => '1287582984',
    'message' => 'Wachtwoordherstel e-mailsjabloon'
  },
  'account activation template' => {
    'lastUpdated' => '1242738901',
    'message' => 'Account activatie e-mail sjabloon'
  },
  'account activation template help' => {
    'lastUpdated' => '1242738980',
    'message' => 'Selecteer een sjabloon voor de account activitatie e-mail dat naar nieuwe gebruikers wordt gestuurd.'
  },
  'account activation template title' => {
    'lastUpdated' => '1242739025',
    'message' => 'WebGUI authenticatie account activatie e-mail template'
  },
  'account deactivate account template title' => {
    'lastUpdated' => '1269433493',
    'message' => 'WebGUI authenticatie deactiveer account sjabloon.'
  },
  'account template' => {
    'lastUpdated' => '1155558248',
    'message' => 'Account sjabloon'
  },
  'account template help' => {
    'lastUpdated' => '1227626546',
    'message' => 'Kies een sjabloon voor het scherm waar de gebruikers hun account kunnen bekijken.'
  },
  'account.form.password' => {
    'lastUpdated' => '1155558528',
    'message' => 'Standaard wachtwoord veld'
  },
  'account.form.password.label' => {
    'lastUpdated' => '1155558520',
    'message' => 'Standaard tekst voor het wachtwoord veld'
  },
  'account.form.passwordConfirm' => {
    'lastUpdated' => '1155895780',
    'message' => 'Standaard wachtwoordbevestiging-formulierveld '
  },
  'account.form.passwordConfirm.label' => {
    'lastUpdated' => '1155896869',
    'message' => 'Standaard tekst voor wachtwoordbevestiging-formulierveld'
  },
  'account.form.username' => {
    'lastUpdated' => '1155900542',
    'message' => 'Standaard gebruikersnaam-formulierveld.'
  },
  'account.form.username.label' => {
    'lastUpdated' => '1155900659',
    'message' => 'Standaard tekst voor het gebruikersnaam-formulierveld.'
  },
  'account.message' => {
    'lastUpdated' => '1155906202',
    'message' => 'Elke boodschap teruggebracht door het systeem. Normaal gesproken weergegeven nadat het formulier is verstuurd. '
  },
  'account.nofields' => {
    'lastUpdated' => '1155906249',
    'message' => 'Standaard-weergave als er geen formulier-onderdelen zijn om weer te geven. '
  },
  'account.noform' => {
    'lastUpdated' => '1155906705',
    'message' => 'Geeft aan of het account-weergave-formulier al dan niet enkele zichtbare velden heeft. '
  },
  'activationUrl' => {
    'lastUpdated' => '1242739066',
    'message' => 'De URL om een nieuw gecre&euml;d account te activeren'
  },
  'anon reg template title' => {
    'lastUpdated' => '1155917612',
    'message' => 'WebGUI authenticatie anonieme registratie-sjabloon'
  },
  'anonymousRegistration.isAllowed' => {
    'lastUpdated' => '1155917744',
    'message' => 'Vlag die aangeeft of anonieme registraties al dan niet zijn toegestaan.'
  },
  'captcha failure' => {
    'lastUpdated' => '1155917795',
    'message' => 'U moet de zes tekens intypen die u in het plaatje ziet, om te bewijzen dat u mens bent. '
  },
  'captcha label' => {
    'lastUpdated' => '1225288274',
    'message' => 'Typ de code uit de afbeelding over. (anti-spam code)'
  },
  'check email for validation' => {
    'lastUpdated' => '1155917843',
    'message' => 'Controleer alstublieft uw e-mail om uw account te activeren.'
  },
  'create account template' => {
    'lastUpdated' => '1155917876',
    'message' => 'Account-sjabloon aanmaken'
  },
  'create account template help' => {
    'lastUpdated' => '1227626586',
    'message' => 'Selecteer een sjabloon voor het tonen van het scherm waar gebruikers een account kunnen aanmaken.'
  },
  'create.form.hidden' => {
    'lastUpdated' => '1155922651',
    'message' => 'Verborgen formulier-velden die vereist zijn om het formulier te versturen. '
  },
  'create.form.oldPassword' => {
    'lastUpdated' => '1155922668',
    'message' => 'Standaard oud wachtwoord formulier-veld.'
  },
  'create.form.oldPassword.label' => {
    'lastUpdated' => '1155922687',
    'message' => 'Standaard tekst voor oud wachtwoord formulier-veld. '
  },
  'create.form.password' => {
    'lastUpdated' => '1155923719',
    'message' => 'Standaard wachtwoord formulier-veld.'
  },
  'create.form.password.label' => {
    'lastUpdated' => '1155923112',
    'message' => 'Standaard tekst voor wachtwoord formulier-veld. '
  },
  'create.form.passwordConfirm' => {
    'lastUpdated' => '1155923710',
    'message' => 'Standaard wachtwoordbevestiging-formulier-veld '
  },
  'create.form.passwordConfirm.label' => {
    'lastUpdated' => '1155923740',
    'message' => 'Standaard tekst voor wachtwoordbevestiging-formulier-veld'
  },
  'create.form.username' => {
    'lastUpdated' => '1156021767',
    'message' => 'Standaard gebruikersnaam formulier-veld.'
  },
  'create.form.username.label' => {
    'lastUpdated' => '1156021794',
    'message' => 'Standaard tekst voor gebruikersnaam formulier-veld.'
  },
  'create.message' => {
    'lastUpdated' => '1156021912',
    'message' => 'Een willekeurig bericht, teruggebracht door het systeem. Wordt normaal gesproken weergegeven nadat het formulier is verstuurd. '
  },
  'createAccount.label' => {
    'lastUpdated' => '1156021939',
    'message' => 'Standaard label voor de anonomie registratie-link.'
  },
  'createAccount.url' => {
    'lastUpdated' => '1156022002',
    'message' => 'URL voor de anonieme registratie-pagina'
  },
  'deactivate account template' => {
    'lastUpdated' => '1269433546',
    'message' => 'Sjabloon deactiveren account'
  },
  'deactivate account template help' => {
    'lastUpdated' => '1269433530',
    'message' => 'Kies een sjabloon waarmee het scherm getoond wordt, waar gebruikers hun account kunnen deactiveren.'
  },
  'deactivate account template title' => {
    'lastUpdated' => '1166625726',
    'message' => 'Sjabloon WebGUI Authenticatie: Deactiveer Login'
  },
  'display account template title' => {
    'lastUpdated' => '1156023652',
    'message' => 'WebGUI authenticatie weergave account-sjabloon '
  },
  'displayTitle' => {
    'lastUpdated' => '1156023671',
    'message' => 'Standaard pagina-titel '
  },
  'email address validation email body' => {
    'lastUpdated' => '1156023714',
    'message' => 'Welkom op onze site. Klik alstublieft op de link hieronder om uw account te activeren. '
  },
  'email address validation email subject' => {
    'lastUpdated' => '1156024486',
    'message' => 'Account activering'
  },
  'email password recovery end message' => {
    'lastUpdated' => '1190025148',
    'message' => 'Geef hieronder een nieuw wachtwoord op voor uw account'
  },
  'email recover password finish message' => {
    'lastUpdated' => '1223545398',
    'message' => 'U zult een e-mail ontvangen met een handleiding voor het opnieuw instellen van uw wachtwoord.'
  },
  'email recover password finish message1' => {
    'lastUpdated' => '1190025130',
    'message' => 'Een email is verzonden naar '
  },
  'email recover password finish message2' => {
    'lastUpdated' => '1190025120',
    'message' => 'met instructies om uw wachtwoord opnieuw in te stellen.'
  },
  'email recover password start message' => {
    'lastUpdated' => '1190025102',
    'message' => 'Geef hieronder hetzij uw emailadres hetzij uw gebruikersnaam om uw wachtwoord opnieuw op te vragen.'
  },
  'email validation confirmed' => {
    'lastUpdated' => '1231520400',
    'message' => 'Bedankt voor het activeren van uw account. U kunt nu inloggen met uw gebruikersnaam en wachtwoord.'
  },
  'error password nonWordCharacters' => {
    'lastUpdated' => '1190025075',
    'message' => 'Wachtwoorden moeten ten minste %s vreemde tekens bevatten (zoals "!", "@" of "$").'
  },
  'error password requiredDigits' => {
    'lastUpdated' => '1190025049',
    'message' => 'Wachtwoorden moeten ten minste %s cijfers bevatten.'
  },
  'error password requiredMixedCase' => {
    'lastUpdated' => '1190025033',
    'message' => 'Wachtwoorden moeten ten minste %s hoofdletters bevatten en ten minste een onderkast karakter.'
  },
  'error passwordRecoveryType no profile fields required' => {
    'lastUpdated' => '1190025001',
    'message' => 'Wachtwoorden kunnen niet worden opgegevraagd aan de hand van profielvelden, omdat geen enkel profielveld is ingesteld als verplicht om het wachtwoord opnieuw te mogen instellen.'
  },
  'expired password template' => {
    'lastUpdated' => '1156024584',
    'message' => 'Verlopen wachtwoord-sjabloon '
  },
  'expired password template help' => {
    'lastUpdated' => '1227626639',
    'message' => 'Kies een sjabloon voor het tonen van het scherm waar gebruikers een nieuw wachtwoord kunnen opgeven als het oude verlopen is.'
  },
  'expired template title' => {
    'lastUpdated' => '1156034449',
    'message' => 'WebGUI authenticatie wachtwoord verlopen-sjabloon '
  },
  'expired.form.footer' => {
    'lastUpdated' => '1156034519',
    'message' => 'De vereiste formulier-onderdelen die na het wachtwoord verlopen pagina-formulier komen. '
  },
  'expired.form.header' => {
    'lastUpdated' => '1156034562',
    'message' => 'De vereiste formulier-onderdelen die bovenaan de wachtwoord verlopen-pagina komen. '
  },
  'expired.form.hidden' => {
    'lastUpdated' => '1156034602',
    'message' => 'Verborgen formulier-velden die vereist zijn om het formulier te versturen.  '
  },
  'expired.form.password' => {
    'lastUpdated' => '1156034627',
    'message' => 'Standaard wachtwoord formulier-veld. '
  },
  'expired.form.password.label' => {
    'lastUpdated' => '1156034652',
    'message' => 'Standaard tekst voor wachtwoord formulier-veld. '
  },
  'expired.form.passwordConfirm' => {
    'lastUpdated' => '1156034680',
    'message' => 'Standaard wachtwoord bevestigen formulier-veld.'
  },
  'expired.form.passwordConfirm.label' => {
    'lastUpdated' => '1156034705',
    'message' => 'Standaard tekst voor wachtwoord bevestigen formulier-veld'
  },
  'expired.form.submit' => {
    'lastUpdated' => '1156034822',
    'message' => 'De standaard verzend-knop voor het wachtwoord verlopen-formulier.'
  },
  'expired.message' => {
    'lastUpdated' => '1156034889',
    'message' => 'Een willekeurig bericht, teruggebracht door het systeem. Normaal gesproken weergegeven nadat het formulier is verzonden. '
  },
  'login template' => {
    'lastUpdated' => '1156034900',
    'message' => 'Login-sjabloon'
  },
  'login template help' => {
    'lastUpdated' => '1227626695',
    'message' => 'Kies een sjabloon voor het inlogscherm. Dit is anders dan de macros waarmee login formulieren getoond worden.'
  },
  'login template title' => {
    'lastUpdated' => '1156035103',
    'message' => 'WebGUI authenticatie login-sjabloon'
  },
  'login.form.email' => {
    'lastUpdated' => '1156035125',
    'message' => 'Standaard e-mail formulier-veld.'
  },
  'login.form.email.label' => {
    'lastUpdated' => '1156035146',
    'message' => 'Standaard tekst voor e-mail formulier-veld'
  },
  'login.label' => {
    'lastUpdated' => '1156035496',
    'message' => 'Standaard tekst label voor login pagina-link.'
  },
  'login.message' => {
    'lastUpdated' => '1156035538',
    'message' => 'Een willekeurig bericht, teruggebracht door het systeem. Normaal gesproken weergegeven nadat het formulier is verzonden.'
  },
  'login.url' => {
    'lastUpdated' => '1156035552',
    'message' => 'URL voor de login-pagina.'
  },
  'new password help' => {
    'lastUpdated' => '1190024958',
    'message' => 'Geef hier uw nieuwe wachtwoord'
  },
  'new password label' => {
    'lastUpdated' => '1190024946',
    'message' => 'Nieuw wachtwoord'
  },
  'new password verify' => {
    'lastUpdated' => '1190024938',
    'message' => 'Nieuw wachtwoord (ter bevestiging)'
  },
  'new password verify help' => {
    'lastUpdated' => '1190024920',
    'message' => 'Wachtwoord (ter bevestiging)'
  },
  'newUser_password' => {
    'lastUpdated' => '1242739151',
    'message' => 'Het wachtwoord voor de nieuwe gebruiker'
  },
  'newUser_username' => {
    'lastUpdated' => '1242739178',
    'message' => 'Gebruikersnaam van registrerende gebruiker'
  },
  'no email address' => {
    'lastUpdated' => '1229530937',
    'message' => 'Deze account heeft geen bijbehorend e-mail adres. Wachtwoord herstel via e-mail is niet mogelijk.'
  },
  'no registration hack' => {
    'lastUpdated' => '1156035603',
    'message' => 'Voltooi anonieme registratie door createAccountSave meteen vanaf de URL aan te roepen. '
  },
  'password recovery disabled' => {
    'lastUpdated' => '1213626099',
    'message' => 'Deze account is uitgezet. Het wachtwoord kan niet worden hersteld totdat de account geactiveerd is.'
  },
  'password recovery email hoverHelp' => {
    'lastUpdated' => '1190024896',
    'message' => 'Geef uw emailadres in'
  },
  'password recovery email label' => {
    'lastUpdated' => '1190024884',
    'message' => 'Emailadres'
  },
  'password recovery email template help' => {
    'lastUpdated' => '1287583023',
    'message' => 'Kies een sjabloon voor de stijl van de e-mail die gestuurd wordt bij het herstel van wachtwoorden.'
  },
  'password recovery login hoverHelp' => {
    'lastUpdated' => '1190024874',
    'message' => 'Geef uw gebruikersnaam in '
  },
  'password recovery login label' => {
    'lastUpdated' => '1190024863',
    'message' => 'Loginnaam'
  },
  'password recovery multiple results' => {
    'lastUpdated' => '1166625795',
    'message' => 'Sorry, het wachtwoord voor deze login kan niet worden gevonden. Neem contact op met de webmaster of een systeembeheerder.'
  },
  'password recovery no results' => {
    'lastUpdated' => '1166625828',
    'message' => 'Er werden geen gebruikers gevonden bij deze profielgegevens. Probeert u het opnieuw.'
  },
  'password recovery no username' => {
    'lastUpdated' => '1166780076',
    'message' => 'Voor het herstellen van uw wachtwoord is de gebruikersnaam vereist.'
  },
  'password recovery template' => {
    'lastUpdated' => '1156035692',
    'message' => 'Wachtwoord terughalen-sjabloon'
  },
  'password recovery template help' => {
    'lastUpdated' => '1227626733',
    'message' => 'Selecteer een sjabloon voor het scherm waar gebruikers een verloren wachtwoord kunnen herstellen.'
  },
  'recover password banner' => {
    'lastUpdated' => '1190024852',
    'message' => 'Wachtwoord opnieuw opvragen'
  },
  'recover password email text1' => {
    'lastUpdated' => '1272876202',
    'message' => 'Uw verzoek om het wachtwoord opnieuw in te stellen is ontvangen '
  },
  'recover password email text2' => {
    'lastUpdated' => '1190024797',
    'message' => 'Klik op de link hieronder om de site te bezoeken en daar uw wachtwoord opnieuw in te stellen.'
  },
  'recover password email text3' => {
    'lastUpdated' => '1208528557',
    'message' => 'Als u niet heeft verzocht uw wachtwoord opnieuw in te stellen, neemt u dan contact op met de systeembeheerder door dit bericht te beantwoorden.'
  },
  'recover password not found' => {
    'lastUpdated' => '1190024732',
    'message' => 'Er is geen gebruiker gevonden bij de gegevens die zijn opgegeven.'
  },
  'recover.form.footer' => {
    'lastUpdated' => '1156035792',
    'message' => 'De vereiste formulier-onderdelen die na het wachtwoord terughalen pagina-formulier komen.'
  },
  'recover.form.header' => {
    'lastUpdated' => '1156035829',
    'message' => 'De vereiste formulier-onderdelen die bovenaan de wachtwoord terughalen-pagina komen. '
  },
  'recover.form.hidden' => {
    'lastUpdated' => '1156035856',
    'message' => 'Verborgen formulier-velden die vereist zijn om het formulier te versturen.'
  },
  'recover.form.submit' => {
    'lastUpdated' => '1156035892',
    'message' => 'De standaard verzend-knop voor het wachtwoord terughalen-formulier. '
  },
  'recover.message' => {
    'lastUpdated' => '1156035939',
    'message' => 'Een willekeurig bericht, teruggebracht door het systeem. Normaal gesproken weergegeven nadat het formulier is verzonden. '
  },
  'recoverFormProfile' => {
    'lastUpdated' => '1208528722',
    'message' => 'Loop door de profielvelden, die nodig zijn voor het opvragen van het wachtwoord.'
  },
  'recoverFormProfile formElement' => {
    'lastUpdated' => '1166625917',
    'message' => 'Een formulier-element voor het profielveld. '
  },
  'recoverFormProfile id' => {
    'lastUpdated' => '1166625932',
    'message' => 'De ID van het profielveld.'
  },
  'recoverFormProfile label' => {
    'lastUpdated' => '1166625954',
    'message' => 'Het label - in meerdere talen beschikbaar - voor het profielveld.'
  },
  'recoverFormUsername' => {
    'lastUpdated' => '1166625979',
    'message' => 'Formulierveld Gebruikersnaam voor het opvragen van het wachtwoord. '
  },
  'recoverFormUsernameLabel' => {
    'lastUpdated' => '1166626041',
    'message' => 'Label - in meerdere talen beschikbaar - voor het formulierveld "username" (gebruikersnaam) voor het opvragen van het wachtwoord. '
  },
  'recoverPassword.isAllowed' => {
    'lastUpdated' => '1156036017',
    'message' => 'Vlag die aangeeft of het wachtwoord terughalen al dan niet is ingeschakeld '
  },
  'recoverPassword.label' => {
    'lastUpdated' => '1156036037',
    'message' => 'Standaard label voor de wachtwoord terughalen-link'
  },
  'recoverPassword.url' => {
    'lastUpdated' => '1156036058',
    'message' => 'URL voor de wachtwoord terughalen-link. '
  },
  'recoverPasswordUrl' => {
    'lastUpdated' => '1287583050',
    'message' => 'De URL waar de gebruiker het wachtwoord opnieuw kan instellen.'
  },
  'recovery email template title' => {
    'lastUpdated' => '1287583106',
    'message' => 'WebGUI authenticatie wachtwoordherstel e-mailsjabloon'
  },
  'recovery template title' => {
    'lastUpdated' => '1154000828',
    'message' => 'Wachtwoord terugwin template (WebGui authenticatie)'
  },
  'require username for password recovery' => {
    'lastUpdated' => '1166626081',
    'message' => 'Is het opgeven van de gebruikersnaam verplicht bij het opvragen van het wachtwoord?'
  },
  'setting passwordRecoveryType email' => {
    'lastUpdated' => '1190024708',
    'message' => 'Emailadres'
  },
  'setting passwordRecoveryType none' => {
    'lastUpdated' => '1190024700',
    'message' => 'Nee'
  },
  'setting passwordRecoveryType profile' => {
    'lastUpdated' => '1190024693',
    'message' => 'Profielveld'
  },
  'setting webguiNonWordCharacters' => {
    'lastUpdated' => '1190024684',
    'message' => 'Minimaal aantal vreemde tekens in wachtwoord'
  },
  'setting webguiNonWordCharacters help' => {
    'lastUpdated' => '1227626799',
    'message' => 'Het aantal karakters dat geen letters is wat vereist is voor het wachtwoord, zoals interpunctie tekens.'
  },
  'setting webguiRequiredDigits' => {
    'lastUpdated' => '1190024663',
    'message' => 'Minimaal aantal cijfers in wachtwoord'
  },
  'setting webguiRequiredDigits help' => {
    'lastUpdated' => '1227626822',
    'message' => 'Hoeveel cijfers moeten er in het wachtwoord zitten?'
  },
  'setting webguiRequiredMixedCase' => {
    'lastUpdated' => '1190024642',
    'message' => 'Aantal verplichte hoofdletters in het wachtwoord'
  },
  'setting webguiRequiredMixedCase help' => {
    'lastUpdated' => '1227626871',
    'message' => 'Deze instelling vereist dat de gebruiker hoofdletters in het wachtwoord heeft. Kleine letters zijn niet vereist.'
  },
  'subtitle' => {
    'lastUpdated' => '1227626920',
    'message' => 'Extra instructies voor het formulier. Dit hoeft niet in alle wachtwoord herstel sjablonen gedefini&euml;erd te zijn.'
  },
  'title' => {
    'lastUpdated' => '1166626092',
    'message' => 'Standaard paginatitel'
  },
  'token already used' => {
    'lastUpdated' => '1221207657',
    'message' => 'Deze voucher voor het herstellen van het wachtwoord is al gebruikt.'
  },
  'topicName' => {
    'lastUpdated' => '1154000645',
    'message' => 'WebGui authenticatie'
  },
  'use captcha' => {
    'lastUpdated' => '1154000570',
    'message' => 'Captcha afbeelding gebruiken?'
  },
  'use captcha help' => {
    'lastUpdated' => '1227626966',
    'message' => 'Als dit op Ja staat, moet de gebruiker tekst uit een captcha afbeelding invoeren als onderdeel van het aanmaken van de account.'
  },
  'use email as username description' => {
    'lastUpdated' => '1246972648',
    'message' => 'Wanneer dit op ja staat, toont het registratie formulier geen veld met de gebruikersnaam. Het ingevoerde -mail adres wordt automatisch als gebruikersnaam gebruikt.'
  },
  'use email as username label' => {
    'lastUpdated' => '1246972676',
    'message' => 'E-mailadres als gebruikersnaam gebruiken'
  },
  'validate email' => {
    'lastUpdated' => '1154000540',
    'message' => 'E-mailadressen bevestigen?'
  },
  'validate email help' => {
    'lastUpdated' => '1227627112',
    'message' => 'Moet WebGUI een e-mail met een link om hun account te starten sturen naar de gebruikers. Dit gaat onafhankelijk van het welkomst bericht. De account zal niet actief zijn totdat de link is bezocht. Accounts die niet geactiveerd worden zullen na een zekere, instelbare, tijd verlopen. Deze periode wordt in een workflow ingesteld.'
  },
  'webguiPasswordRecovery hoverHelp' => {
    'lastUpdated' => '1199787271',
    'message' => 'Selecteer hier &quot;Profiel veld&quot; om gebruikers toe te staan met een specifieke combinatie van gegevens uit hun profiel hun wachtwoord opnieuw op te vragen. Voordat deze optie ook daadwerkelijk werkt, moet bij ten minste &eacute;&eacute;n profielveld de optie &quot;Verplicht voor opvragen wachtwoord&quot; geselecteerd zijn. Het is zeer aan te raden meerdere profielvelden te kiezen, om gokken te ontmoedigen. Bedenk: iedereen die alle velden voor een gebruiker te weten kan komen of kan raden heeft de mogelijkheid het wachtwoord voor deze gebruiker opnieuw in te stellen. Selecteer E-mail om gebruikers een e-mail te kunnen zenden met een link via welke ze hun wachtwoord opnieuw kunnen instellen.'
  },
  'webguiPasswordRecoveryRequireUsername hoverHelp' => {
    'lastUpdated' => '1166627245',
    'message' => 'Selecteer "Ja" om gebruikers te verplichten ook hun gebruikersnaam op te geven wanneer ze hun wachtwoord opnieuw opvragen. In het andere geval kunnen gebruikers hun wachtwoord opnieuw instellen en zichzelf inloggen wanneer ze de profielvelden kennen die verplicht zijn voor het opvragen van het wachtwoord, zelfs al zijn ze hun gebruikersnaam vergeten. '
  },
  'welcome message template' => {
    'lastUpdated' => '1242739262',
    'message' => 'Welkomstbericht sjabloon'
  },
  'welcome message template help' => {
    'lastUpdated' => '1242739329',
    'message' => 'Selecteer een sjabloon voor het welkomstbericht dat wordt verstuurd naar nieuwe gebruikers'
  },
  'welcome message template title' => {
    'lastUpdated' => '1242739391',
    'message' => 'WebGUI authenticatie welkomstbericht sjabloon'
  },
  'welcomeMessage' => {
    'lastUpdated' => '1242739452',
    'message' => 'Het welkomstbericht zo als aangegeven in de authenticatie instellingen.'
  }
}
;

1;
